summaryrefslogtreecommitdiff
path: root/modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h
diff options
context:
space:
mode:
authorWilliam R. Otte <wotte@dre.vanderbilt.edu>2009-06-15 14:07:29 +0000
committerWilliam R. Otte <wotte@dre.vanderbilt.edu>2009-06-15 14:07:29 +0000
commitba7f1f47a76747d5da7ecbb6b731feca4c25dabd (patch)
treef6239781ff1410cb9442ca129db6a83f50863634 /modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h
parent0093fda0616630c93c003ab4b3fe0a11228d7b12 (diff)
downloadATCD-ba7f1f47a76747d5da7ecbb6b731feca4c25dabd.tar.gz
Mon Jun 15 14:05:45 UTC 2009 William R. Otte <wotte@dre.vanderbilt.edu>
Diffstat (limited to 'modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h')
-rw-r--r--modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h101
1 files changed, 57 insertions, 44 deletions
diff --git a/modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h b/modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h
index b25191f0a4a..66ec39a1ae7 100644
--- a/modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h
+++ b/modules/CIAO/DAnCE/tests/CIAO/Components/SimplePublisher_exec.h
@@ -1,25 +1,35 @@
-// $Id$
+// -*- C++ -*-
//
-// **** Code generated by the ****
-// **** Component Integrated ACE ORB (CIAO) CIDL Compiler ****
-// CIAO has been developed by:
+// $Id$
+
+// **** Code generated by the The ACE ORB (TAO) IDL Compiler v1.6.9 ****
+// TAO and the TAO IDL Compiler have been developed by:
// Center for Distributed Object Computing
// Washington University
// St. Louis, MO
// USA
// http://www.cs.wustl.edu/~schmidt/doc-center.html
-// CIDL Compiler has been developed by:
+// and
+// Distributed Object Computing Laboratory
+// University of California at Irvine
+// Irvine, CA
+// USA
+// http://doc.ece.uci.edu/
+// and
// Institute for Software Integrated Systems
// Vanderbilt University
// Nashville, TN
// USA
// http://www.isis.vanderbilt.edu/
//
-// Information about CIAO is available at:
-// http://www.dre.vanderbilt.edu/CIAO
+// Information about TAO is available at:
+// http://www.cs.wustl.edu/~schmidt/TAO.html
+
+// TAO_IDL - Generated from
+// be/be_codegen.cpp:1301
-#ifndef CIAO_SIMPLEPUBLISHER_EXEC_H
-#define CIAO_SIMPLEPUBLISHER_EXEC_H
+#ifndef CIAO_SIMPLEPUBLISHER_EXEC_H_
+#define CIAO_SIMPLEPUBLISHER_EXEC_H_
#include /**/ "ace/pre.h"
@@ -29,70 +39,73 @@
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-#include "SimplePublisher_exec_export.h"
+#include /**/ "SimplePublisher_exec_export.h"
#include "tao/LocalObject.h"
-namespace CIDL_SimplePublisher_Impl
+namespace CIAO_Simple_SimplePublisher_Impl
{
class SIMPLEPUBLISHER_EXEC_Export SimplePublisher_exec_i
: public virtual SimplePublisher_Exec,
public virtual ::CORBA::LocalObject
{
- public:
+ public:
SimplePublisher_exec_i (void);
virtual ~SimplePublisher_exec_i (void);
-
- // Supported or inherited operations.
-
- // Attribute operations.
-
+
+ // Supported operations and attributes.
+
+ // Component attributes.
+
// Port operations.
-
- // Operations from Components::SessionComponent
-
+
+ // Operations from Components::SessionComponent.
+
virtual void
set_session_context (
::Components::SessionContext_ptr ctx);
-
- virtual void configuration_complete ();
-
- virtual void ccm_activate ();
-
- virtual void ccm_passivate ();
-
- virtual void ccm_remove ();
-
- private:
+
+ virtual void configuration_complete (void);
+
+ virtual void ccm_activate (void);
+ virtual void ccm_passivate (void);
+ virtual void ccm_remove (void);
+
+ private:
::Simple::CCM_SimplePublisher_Context_var context_;
};
+
+ extern "C" SIMPLEPUBLISHER_EXEC_Export ::Components::EnterpriseComponent_ptr
+ create_Simple_SimplePublisher_Impl (void);
+}
+namespace CIAO_Simple_SimplePublisher_Impl
+{
class SIMPLEPUBLISHER_EXEC_Export SimplePublisherHome_exec_i
: public virtual SimplePublisherHome_Exec,
public virtual ::CORBA::LocalObject
{
- public:
+ public:
SimplePublisherHome_exec_i (void);
+
virtual ~SimplePublisherHome_exec_i (void);
-
- // Supported or inherited operations.
-
- // Home operations.
-
- // Factory and finder operations.
-
- // Attribute operations.
-
+
+ // All operations and attributes.
+
+ // Factory operations.
+
+ // Finder operations.
+
// Implicit operations.
-
+
virtual ::Components::EnterpriseComponent_ptr
- create ();
+ create (void);
};
-
+
extern "C" SIMPLEPUBLISHER_EXEC_Export ::Components::HomeExecutorBase_ptr
create_Simple_SimplePublisherHome_Impl (void);
}
#include /**/ "ace/post.h"
-#endif /* CIAO_SIMPLEPUBLISHER_EXEC_H */
+#endif /* ifndef */